@@ -145,6 +145,34 @@ filtered_genes <- filter_genes_TSP(data_object = object,
                                    verbose = TRUE)
 filtered_genes
 
+## ---- eval = FALSE------------------------------------------------------------
+#  # using the object that is generated by ReadData
+#  # we can create genes object with all genes to skip filtering step
+#  
+#  # Get the class names
+#  classes <- unique(object$data$Labels)
+#  
+#  # create empty genes object
+#  genes_all <- list(OnevsrestScheme = list(filtered_genes = NULL,
+#                                           calls = c()))
+#  class(genes_all) <- "OnevsrestScheme_genes_TSP"
+#  
+#  # prepare the slots for each class
+#  tmp <- vector("list", length(classes))
+#  names(tmp) <- classes
+#  
+#  genes_all$OnevsrestScheme$filtered_genes <- tmp
+#  genes_all$OnevsrestScheme$calls <- c()
+#  genes_all
+#  
+#  # fill the gene object in each slot
+#  for (i in classes) {
+#    genes_all$OnevsrestScheme$filtered_genes[[i]] <- rownames(object$data$Data)
+#  }
+#  
+#  # This is the gene object with all genes
+#  genes_all
+
 ## -----------------------------------------------------------------------------
 # Let's train our model
 classifier <- train_one_vs_rest_TSP(data_object = object,
@@ -391,6 +419,55 @@ plot_binary_RF(Data = test,
                show_predictions = TRUE,
                title = "Testing data")
 
+## ---- eval=FALSE, tidy=FALSE--------------------------------------------------
+#  # For one-vs-rest scheme settings:
+#  # one_vs_rest gene filtering with k_range of 10:50
+#  object <- ReadData(Data = training_data,
+#                     Labels = Train_Classes)
+#  
+#  filtered_genes <- filter_genes_TSP(data_object = object,
+#                                     featureNo = 1000, UpDown = TRUE,
+#                                     filter = "one_vs_rest")
+#  
+#  classifier_1_vs_r <- train_one_vs_rest_TSP(data_object = object,
+#                                             filtered_genes = filtered_genes,
+#                                             k_range = 10:50, disjoint = TRUE,
+#                                             include_pivot = FALSE,
+#                                             platform_wise_scores = FALSE,
+#                                             one_vs_one_scores = FALSE)
+#  
+#  # For RF scheme settings:
+#  # Settings represents a large model to show calculation time with high number of genes/rules
+#  object <- ReadData(Data = training_data,
+#                     Labels = Train_Classes)
+#  
+#  sorted_genes  <- sort_genes_RF(object)
+#  
+#  sorted_rules  <- sort_rules_RF(data_object = object,
+#                                 sorted_genes_RF = sorted_genes,
+#                                 genes_altogether = 200,
+#                                 genes_one_vs_rest = 200)
+#  
+#  classifier_RF <- train_RF(data_object = object,
+#                            sorted_rules_RF = sorted_rules,
+#                            rules_one_vs_rest = 200,
+#                            rules_altogether = 200,
+#                            run_boruta = FALSE, gene_repetition = 1)
+#  
+#  # For DT scheme from Rgtsp package:
+#  # default settings with min.score=0.6 (to avoid running out of rules with the default setting 0.75)
+#  #devtools::install_github("bioinfo-recetox/Rgtsp")
+#  library(Rgtsp)
+#  classifier_DT <- mtsp(X = t(as.matrix(training_data)),
+#                        y = Train_Classes,
+#                        min.score=0.60)
+
+## ---- fig.cap="Overall accuracy for the three pair-based approaches. X-axis show the performance of different models trained on training datasets with different sizes.", echo=FALSE, message=FALSE----
+knitr::include_graphics("images/Accuracy_final.png")
+
+## ---- out.height="90%",  fig.cap="Average of the overall training time including the gene and rules filtering and model training. Training repeated 5 times for each model and the bars show the average time.", echo=FALSE, message=FALSE----
+knitr::include_graphics("images/Both_CPUs.png")
+
 ## -----------------------------------------------------------------------------
 sessionInfo()
 
